Pygments — Rider 0.1.8a documentation

### Navigation

- index
- Rider 0.1.8a documentation »

# Pygments

Pygments is a syntax highlighting package written in Python.

It is a generic syntax highlighter suitable for use in code hosting, forums, wikis or other applications that need to prettify source code. Highlights are:

- a wide range of over 300 languages and other text formats is supported
- special attention is paid to details, increasing quality by a fair amount
- support for new languages and formats are added easily
- a number of output formats, presently HTML, LaTeX, RTF, SVG, all image formats that PIL supports and ANSI sequences
- it is usable as a command-line tool and as a library

copyright: | Copyright 2006-2014 by the Pygments team, see AUTHORS.
license: | BSD, see LICENSE for details.

### Navigation

- index
- Rider 0.1.8a documentation »